@@ -24,13 +24,15 @@
 
 #include <QDialog>
 #include <KContacts/Address>
+
 class QButtonGroup;
+
+namespace ContactEditor {
 /**
  * Dialog for creating a new address types.
  *
  * @note This dialog is only used by AddressTypeCombo.
  */
-namespace ContactEditor {
 class AddressTypeDialog : public QDialog
 {
     Q_OBJECT
@@ -41,7 +43,7 @@ public:
     KContacts::Address::Type type() const;
 
 private:
-    QButtonGroup *mGroup;
+    QButtonGroup *mGroup = nullptr;
 
     KContacts::Address::TypeList mTypeList;
 };
